pub struct StoreTransaction { /* private fields */ }Expand description
A Transaction DB
Implementations
Sourceimpl StoreTransaction
impl StoreTransaction
Sourcepub fn insert_raw(
&self,
col: Col,
key: &[u8],
value: &[u8],
) -> Result<(), Error>
pub fn insert_raw( &self, col: Col, key: &[u8], value: &[u8], ) -> Result<(), Error>
Inserts a raw key-value pair into the specified column.
Sourcepub fn delete(&self, col: Col, key: &[u8]) -> Result<(), Error>
pub fn delete(&self, col: Col, key: &[u8]) -> Result<(), Error>
Deletes a key from the specified column.
Sourcepub fn commit(&self) -> Result<(), Error>
pub fn commit(&self) -> Result<(), Error>
Commits the transaction, writing all changes to the database.
Sourcepub fn get_snapshot(&self) -> StoreTransactionSnapshot<'_>
pub fn get_snapshot(&self) -> StoreTransactionSnapshot<'_>
Returns a snapshot of the transaction’s current state.
Sourcepub fn get_update_for_tip_hash(
&self,
snapshot: &StoreTransactionSnapshot<'_>,
) -> Option<Byte32>
pub fn get_update_for_tip_hash( &self, snapshot: &StoreTransactionSnapshot<'_>, ) -> Option<Byte32>
Gets the tip header hash for update, locking the row in the transaction.
Sourcepub fn insert_tip_header(&self, h: &HeaderView) -> Result<(), Error>
pub fn insert_tip_header(&self, h: &HeaderView) -> Result<(), Error>
Inserts or updates the tip header hash in the store.
Sourcepub fn insert_block(&self, block: &BlockView) -> Result<(), Error>
pub fn insert_block(&self, block: &BlockView) -> Result<(), Error>
Inserts a block into the store.
Sourcepub fn delete_block(&self, block: &BlockView) -> Result<(), Error>
pub fn delete_block(&self, block: &BlockView) -> Result<(), Error>
Deletes a block from the store.
Sourcepub fn insert_block_ext(
&self,
block_hash: &Byte32,
ext: &BlockExt,
) -> Result<(), Error>
pub fn insert_block_ext( &self, block_hash: &Byte32, ext: &BlockExt, ) -> Result<(), Error>
Inserts block extension data.
Sourcepub fn attach_block(&self, block: &BlockView) -> Result<(), Error>
pub fn attach_block(&self, block: &BlockView) -> Result<(), Error>
Attaches a block to the main chain, indexing its transactions and uncles.
Sourcepub fn detach_block(&self, block: &BlockView) -> Result<(), Error>
pub fn detach_block(&self, block: &BlockView) -> Result<(), Error>
Detaches a block from the main chain, removing its transaction and uncle indices.
Sourcepub fn insert_block_epoch_index(
&self,
block_hash: &Byte32,
epoch_hash: &Byte32,
) -> Result<(), Error>
pub fn insert_block_epoch_index( &self, block_hash: &Byte32, epoch_hash: &Byte32, ) -> Result<(), Error>
Inserts the block-to-epoch index mapping.
Sourcepub fn insert_epoch_ext(
&self,
hash: &Byte32,
epoch: &EpochExt,
) -> Result<(), Error>
pub fn insert_epoch_ext( &self, hash: &Byte32, epoch: &EpochExt, ) -> Result<(), Error>
Inserts epoch extension data.
Sourcepub fn insert_current_epoch_ext(&self, epoch: &EpochExt) -> Result<(), Error>
pub fn insert_current_epoch_ext(&self, epoch: &EpochExt) -> Result<(), Error>
Inserts the current epoch extension data.
Sourcepub fn insert_cells(
&self,
cells: impl Iterator<Item = (OutPoint, CellEntry, Option<CellDataEntry>)>,
) -> Result<(), Error>
pub fn insert_cells( &self, cells: impl Iterator<Item = (OutPoint, CellEntry, Option<CellDataEntry>)>, ) -> Result<(), Error>
Inserts multiple cells into the store.
Sourcepub fn delete_cells(
&self,
out_points: impl Iterator<Item = OutPoint>,
) -> Result<(), Error>
pub fn delete_cells( &self, out_points: impl Iterator<Item = OutPoint>, ) -> Result<(), Error>
Deletes multiple cells from the store.
Sourcepub fn insert_header_digest(
&self,
position_u64: u64,
header_digest: &HeaderDigest,
) -> Result<(), Error>
pub fn insert_header_digest( &self, position_u64: u64, header_digest: &HeaderDigest, ) -> Result<(), Error>
Inserts a header digest.